@@ -1,5 +1,4 @@
 import lkml as looker
-from pprint import pprint
 from google.oauth2 import service_account
 import pandas_gbq
 from contextlib import redirect_stdout
@@ -10,7 +9,7 @@ import json
 import sys
 from itertools import chain
 
-from droughty.dbt_test_base_dict import d1
+from droughty.dbt_test_base_dict import dbt_test_dict
 from droughty.dbt_test_field_base import described_columns_list
 
 import sys
@@ -75,7 +74,7 @@ def get_all_values(nested_dictionary):
 
     return res
 
-nested_dictionary = d1
+nested_dictionary = dbt_test_dict
 
 get_all_values(nested_dictionary)
 
